==> gs2-java-sdk-3.1.8-sources.jar: io/gs2/friend/request/UpdateProfileRequest.java <==
/*
 * Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package io.gs2.friend.request;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.JsonNode;
import io.gs2.core.control.Gs2BasicRequest;

@SuppressWarnings("serial")
@JsonIgnoreProperties(ignoreUnknown=true)
public class UpdateProfileRequest extends Gs2BasicRequest<UpdateProfileRequest> {
    private String namespaceName;
    private String accessToken;
    private String publicProfile;
    private String followerProfile;
    private String friendProfile;

	public String getNamespaceName() {
		return namespaceName;
	}

	public void setNamespaceName(String namespaceName) {
		this.namespaceName = namespaceName;
	}

	public UpdateProfileRequest withNamespaceName(String namespaceName) {
		this.namespaceName = namespaceName;
		return this;
	}

	public String getAccessToken() {
		return accessToken;
	}

	public void setAccessToken(String accessToken) {
		this.accessToken = accessToken;
	}

	public UpdateProfileRequest withAccessToken(String accessToken) {
		this.accessToken = accessToken;
		return this;
	}

	public String getPublicProfile() {
		return publicProfile;
	}

	public void setPublicProfile(String publicProfile) {
		this.publicProfile = publicProfile;
	}

	public UpdateProfileRequest withPublicProfile(String publicProfile) {
		this.publicProfile = publicProfile;
		return this;
	}

	public String getFollowerProfile() {
		return followerProfile;
	}

	public void setFollowerProfile(String followerProfile) {
		this.followerProfile = followerProfile;
	}

	public UpdateProfileRequest withFollowerProfile(String followerProfile) {
		this.followerProfile = followerProfile;
		return this;
	}

	public String getFriendProfile() {
		return friendProfile;
	}

	public void setFriendProfile(String friendProfile) {
		this.friendProfile = friendProfile;
	}

	public UpdateProfileRequest withFriendProfile(String friendProfile) {
		this.friendProfile = friendProfile;
		return this;
	}

    public static UpdateProfileRequest fromJson(JsonNode data) {
        if (data == null) {
            return null;
        }
        return new UpdateProfileRequest()
            .withNamespaceName(data.get("namespaceName") == null || data.get("namespaceName").isNull() ? null : data.get("namespaceName").asText())
            .withAccessToken(data.get("accessToken") == null || data.get("accessToken").isNull() ? null : data.get("accessToken").asText())
            .withPublicProfile(data.get("publicProfile") == null || data.get("publicProfile").isNull() ? null : data.get("publicProfile").asText())
            .withFollowerProfile(data.get("followerProfile") == null || data.get("followerProfile").isNull() ? null : data.get("followerProfile").asText())
            .withFriendProfile(data.get("friendProfile") == null || data.get("friendProfile").isNull() ? null : data.get("friendProfile").asText());
    }

    public JsonNode toJson() {
        return new ObjectMapper().valueToTree(
            new HashMap<String, Object>() {{
                put("namespaceName", getNamespaceName());
                put("accessToken", getAccessToken());
                put("publicProfile", getPublicProfile());
                put("followerProfile", getFollowerProfile());
                put("friendProfile", getFriendProfile());
            }}
        );
    }
}

==> gs2-java-sdk-3.1.196-sources.jar: io/gs2/friend/request/UpdateProfileRequest.java <==
/*
 * Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package io.gs2.friend.request;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.JsonNode;
import io.gs2.core.control.Gs2BasicRequest;

@SuppressWarnings("serial")
@JsonIgnoreProperties(ignoreUnknown=true)
public class UpdateProfileRequest extends Gs2BasicRequest<UpdateProfileRequest> {
    private String namespaceName;
    private String accessToken;
    private String publicProfile;
    private String followerProfile;
    private String friendProfile;
    private String duplicationAvoider;
	public String getNamespaceName() {
		return namespaceName;
	}
	public void setNamespaceName(String namespaceName) {
		this.namespaceName = namespaceName;
	}
	public UpdateProfileRequest withNamespaceName(String namespaceName) {
		this.namespaceName = namespaceName;
		return this;
	}
	public String getAccessToken() {
		return accessToken;
	}
	public void setAccessToken(String accessToken) {
		this.accessToken = accessToken;
	}
	public UpdateProfileRequest withAccessToken(String accessToken) {
		this.accessToken = accessToken;
		return this;
	}
	public String getPublicProfile() {
		return publicProfile;
	}
	public void setPublicProfile(String publicProfile) {
		this.publicProfile = publicProfile;
	}
	public UpdateProfileRequest withPublicProfile(String publicProfile) {
		this.publicProfile = publicProfile;
		return this;
	}
	public String getFollowerProfile() {
		return followerProfile;
	}
	public void setFollowerProfile(String followerProfile) {
		this.followerProfile = followerProfile;
	}
	public UpdateProfileRequest withFollowerProfile(String followerProfile) {
		this.followerProfile = followerProfile;
		return this;
	}
	public String getFriendProfile() {
		return friendProfile;
	}
	public void setFriendProfile(String friendProfile) {
		this.friendProfile = friendProfile;
	}
	public UpdateProfileRequest withFriendProfile(String friendProfile) {
		this.friendProfile = friendProfile;
		return this;
	}

	public String getDuplicationAvoider() {
		return duplicationAvoider;
	}

	public void setDuplicationAvoider(String duplicationAvoider) {
		this.duplicationAvoider = duplicationAvoider;
	}

	public UpdateProfileRequest withDuplicationAvoider(String duplicationAvoider) {
		this.duplicationAvoider = duplicationAvoider;
		return this;
	}

    public static UpdateProfileRequest fromJson(JsonNode data) {
        if (data == null) {
            return null;
        }
        return new UpdateProfileRequest()
            .withNamespaceName(data.get("namespaceName") == null || data.get("namespaceName").isNull() ? null : data.get("namespaceName").asText())
            .withAccessToken(data.get("accessToken") == null || data.get("accessToken").isNull() ? null : data.get("accessToken").asText())
            .withPublicProfile(data.get("publicProfile") == null || data.get("publicProfile").isNull() ? null : data.get("publicProfile").asText())
            .withFollowerProfile(data.get("followerProfile") == null || data.get("followerProfile").isNull() ? null : data.get("followerProfile").asText())
            .withFriendProfile(data.get("friendProfile") == null || data.get("friendProfile").isNull() ? null : data.get("friendProfile").asText());
    }

    public JsonNode toJson() {
        return new ObjectMapper().valueToTree(
            new HashMap<String, Object>() {{
                put("namespaceName", getNamespaceName());
                put("accessToken", getAccessToken());
                put("publicProfile", getPublicProfile());
                put("followerProfile", getFollowerProfile());
                put("friendProfile", getFriendProfile());
            }}
        );
    }
}
